# SSplines
A Python library for the evaluation of linear and quadratic simplex splines over the Powell-Sabin 12-split of a triangle.

## Installation

### Using pip



### Local

Clone the repository and navigate to the directory. Run

```bash
python setup.py install
```
and verify that the installation worked by
running

```python
import SSplines
print(dir(SSplines))
```

in an interactive Python shell.
